@@ -2,7 +2,7 @@
 #' @useDynLib collections, .registration = TRUE, .fixes = "C_"
 "_PACKAGE"
 
-dict_hash <- function(key) .Call(C_dict_hash, key)
+# dict_hash <- function(key) .Call(C_dict_hash, key)
 
 #' @title Inspect objects
 #' @description
