@@ -1,6 +1,5 @@
 context("deque")
 
-
 test_that("push, peek and pop", {
     q <- deque()
     q$push(1)$push(2)
@@ -133,3 +132,19 @@ test_that("pushleft NULL", {
     expect_null(q$popleft())
     expect_equal(q$size(), 1)
 })
+
+
+test_that("serialization", {
+    q <- deque()
+    q$push(1)$push(2)
+    q2 <- unserialize(serialize(q, NULL))
+    expect_equal(q2$size(), 2)
+    q2$push(3)
+    expect_equal(q2$size(), 3)
+    q2$pushleft(4)
+    expect_equal(q2$size(), 4)
+    expect_equal(q2$pop(), 3)
+    expect_equal(q2$size(), 3)
+    expect_equal(q2$popleft(), 4)
+    expect_equal(q2$size(), 2)
+})
